import { SvelteComponentTyped } from "svelte";
declare const __propDef: {
    props: {
        /**
             * Active class that will be applied to the active item.
             */ activeClass?: string | undefined;
        /**
             * Amount of space between top of screen and the section to highlight. (Usually your fixed
             * header's height).
             */ offset?: number | undefined;
        /**
             * Amount of space between the top of the screen and the section to highlight when clicking a
             * scrollactive item to scroll. It will use the value of the `offset` prop if none is provided
             * here. Useful when you want to use the `offset` prop to make an item be active as soon as
             * it shows on the screen but still scroll to the top of the section when clicking the item.
             */ scrollOffset?: any;
        /**
             * The selector string of the scroll container element you'd like to use. It defaults to the
             * window object (most common), but you might want to change in case you're using an element
             * as container with overflow.
             */ scrollContainerSelector?: string | undefined;
        /**
             * Enables/disables the scrolling when clicking in a menu item.
             * Disable if you'd like to handle the scrolling by your own.
             */ clickToScroll?: boolean | undefined;
        /**
             * The duration of the scroll animation when clicking to scroll is activated.
             */ duration?: number | undefined;
        /**
             * Defines if the plugin should track the section change when clicking an item to scroll to
             * its section. If set to true, it will always keep track and change the active class to the
             * current section while scrolling, if false, the active class will be immediately applied to
             * the clicked menu item, ignoring the passed sections until the scrolling is over.
             */ alwaysTrack?: boolean | undefined;
        /**
             * Your custom easing value for the click to scroll functionality.
             * It must be a string with 4 values separated by commas in a cubic bezier format.
             */ bezierEasingValue?: string | undefined;
        /**
             * Decides if the URL should be modified with the section id when clicking a scrollactive
             * item.
             */ modifyUrl?: boolean | undefined;
        /**
             * If true the active class will only be applied when a section matches exactly one of the
             * scrollactive items, meaning it will be highlighted when scrolling exactly inside the
             * section. If false (default) it will always highlight the last item which was matched
             * in a section, even if it is already outside that section (and not inside another that's
             * being tracked).
             */ exact?: boolean | undefined;
        /**
             * If true the active class will be applied to the first scrollactive-item before you scroll
             * past it (even if you didn't reach it yet).
             */ highlightFirstItem?: boolean | undefined;
        /**
             * Changes the scrollactive container component html tag.
             */ tag?: string | undefined;
        /**
             * If true the screen will scroll down to the element in the URL when the component is mounted.
             */ scrollOnStart?: boolean | undefined;
        /**
             * Exported function to scroll with svelte-scrollactive to any element in the page.
             */ scrollToElement?: ((target: any) => Promise<void>) | undefined;
    };
    events: {
        itemchanged: CustomEvent<any>;
    } & {
        [evt: string]: CustomEvent<any>;
    };
    slots: {
        default: {};
    };
};
export type ScrollactiveProps = typeof __propDef.props;
export type ScrollactiveEvents = typeof __propDef.events;
export type ScrollactiveSlots = typeof __propDef.slots;
export default class Scrollactive extends SvelteComponentTyped<ScrollactiveProps, ScrollactiveEvents, ScrollactiveSlots> {
    get scrollToElement(): (target: any) => Promise<void>;
}
export {};
